{ config ? {}, system ? builtins.currentSystem, ... }@args:

let
  sources = import ../nix/sources.nix;
  pkgs = import sources.nixpkgs args;
  unstable = import sources.nixpkgs-unstable args;
  new = import sources.nixpkgs-new args;

  callPackage = pkgs.lib.callPackageWith (pkgs // newpkgs);

  newpkgs = {
    alps = callPackage ./alps {};

#    companion = callPackage ./companion {};
    libvips = callPackage ./libvips {};

    docker = pkgs.docker.overrideAttrs (super: {
      moby = super.moby.overrideAttrs (super: {
        extraPath = super.extraPath + ":${pkgs.zfs}/bin";
      });
    });

    linuxPackagesFor = kernel: (pkgs.linuxPackagesFor kernel).extend (_: ksuper: {
      decklink = callPackage ./decklink { kernel = ksuper.kernel; };
    });

    blackmagicDesktopVideo = callPackage ./blackmagic-desktop-video { };

    obs-studio = unstable.obs-studio.overrideAttrs (old: rec {
      src = pkgs.fetchgit {
        url = "https://github.com/lukas2511/obs-studio";
        rev = "93ae2b1c11ad81787d69f30c6c251f02dc72c2f4";
        sha256 = "0zla25bjlqx78rb3fgc2yj8bgb4w4lfq6ans47mpb9nvm5ngx5rn";
        fetchSubmodules = true;
      };

      buildInputs = old.buildInputs ++ [ pkgs.libdrm ];

      # disable browser-source patches which don't fit on this version of obs
      patches = [];
      cmakeFlags = [
        "-DCMAKE_CXX_FLAGS=-DDL_OPENGL=\\\"$(out)/lib/libobs-opengl.so\\\""
        "-DOBS_VERSION_OVERRIDE=27.0.1"
        "-Wno-dev" # kill dev warnings that are useless for packaging
        # is there a better way to change just one flag? (this is where I miss guix tbh)
        # anyways turns browser sources off
        "-DBUILD_BROWSER=OFF"
        "-DCEF_ROOT_DIR=../../cef"
      ];

      wrapLibraries = with (pkgs // newpkgs); [
        xorg.libX11.out
        libvlc
        blackmagicDesktopVideo
        libcxx
        libcxxabi
      ];
      postInstall = ''
        wrapProgram $out/bin/obs \
          --prefix "LD_LIBRARY_PATH" : "${pkgs.lib.makeLibraryPath wrapLibraries}"
      '';
    });

    mattermost = callPackage ./mattermost {};

    # a version of the lounge with some extra css that
    # hides things the hacc-voc doesn't need
    thelounge-hacked = pkgs.stdenv.mkDerivation {
      name = "thelounge-hacked";
      src = pkgs.thelounge;

      phases = [ "buildPhase" "installPhase" ];
      buildPhase = ''
        cp $src/* -r .
        chmod 777 lib/node_modules/thelounge/public/css/style.css
        cat ${./thelounge/css-patch.css} >> lib/node_modules/thelounge/public/css/style.css
      '';

      installPhase = ''
        mkdir -p $out
        cp * -r $out
      '';
    };

    inherit (unstable) bottom vaultwarden vaultwarden-vault;
  };

in pkgs.extend(_: _: newpkgs)
